@@ -30,6 +30,9 @@ def check_isoformat_none_case(v: Optional[str]):
 class HttpMethodType(Enum):
     HTTP_METHOD_GET = 'GET'
     HTTP_METHOD_POST = 'POST'
+    HTTP_METHOD_PUT = 'PUT'
+    HTTP_METHOD_PATCH = 'PATCH'
+    HTTP_METHOD_DELETE = 'DELETE'
 
     def json(self):
         return json.dumps(self, cls=PaymentEncoder)
@@ -52,6 +55,7 @@ class PaymentStatus(Enum):
     STATUS_NOTIFICATION_PENDING = 'NOTIFICATION_PENDING'
     STATUS_COMPLETE = 'COMPLETE'
     STATUS_EXPIRED = 'EXPIRED'
+    STATUS_CANCELED = 'CANCELED'
 
     def json(self):
         return json.dumps(self, cls=PaymentEncoder)
@@ -59,6 +63,7 @@ class PaymentStatus(Enum):
 
 class PaymentType(Enum):
     TYPE_PAGOPA = 'PAGOPA'
+    TYPE_STAMP = 'STAMP'
 
     def json(self):
         return json.dumps(self, cls=PaymentEncoder)
@@ -97,11 +102,29 @@ class PaymentDataSplit(BaseModel):
         return json.dumps(self, cls=PaymentEncoder)
 
 
-class PaymentDataStamp(BaseModel):
-    amount: float
-    collection_data: Optional[str]
-    reason: str
-    meta: dict
+class Document(BaseModel):
+    id: Optional[str]
+    ref: Optional[str]
+    hash: str
+
+    class Config:
+        validate_all = True
+        validate_assignment = True
+
+    def json(self):
+        return json.dumps(self, cls=PaymentEncoder)
+
+
+class Receiver(BaseModel):
+    tax_identification_number: str
+    name: str
+    iban: str
+    address: Optional[str]
+    building_number: Optional[str]
+    postal_code: Optional[str]
+    town_name: Optional[str]
+    country_subdivision: Optional[str]
+    country: Optional[str]
 
     class Config:
         validate_all = True
@@ -115,13 +138,18 @@ class PaymentData(BaseModel):
     transaction_id: Optional[str]
     paid_at: Optional[str]
     expire_at: str
-    amount: float
+    amount: Optional[float]
     currency: CurrencyType
+    type: Optional[PaymentType]
+    reason: Optional[constr(max_length=140)]
     notice_code: Optional[str]
     iud: str
     iuv: Optional[str]
+    receiver: Optional[Receiver]
+    due_type: Optional[str]
+    pagopa_category: Optional[str]
+    document: Optional[Document]
     split: List[Optional[PaymentDataSplit]]
-    stamps: List[Optional[PaymentDataStamp]]
 
     class Config:
         validate_all = True
@@ -161,6 +189,14 @@ class Receipt(OnlinePaymentBegin):
     pass
 
 
+class Confirm(OnlinePaymentBegin):
+    pass
+
+
+class Cancel(OnlinePaymentBegin):
+    pass
+
+
 class Notify(BaseModel):
     url: Optional[str]
     method: Optional[HttpMethodType]
@@ -200,6 +236,8 @@ class Links(BaseModel):
     receipt: Receipt
     notify: Optional[List[Notify]]
     update: Update
+    confirm: Confirm = Confirm(**{'url': None, 'last_opened_at': None, 'method': None})
+    cancel: Cancel = Cancel(**{'url': None, 'last_opened_at': None, 'method': None})
 
     class Config:
         validate_all = True
@@ -240,20 +278,39 @@ class Payer(BaseModel):
         return json.dumps(self, cls=PaymentEncoder)
 
 
+class Debtor(Payer):
+    pass
+
+
+class Fault(BaseModel):
+    title: str
+    detail: str
+    type: str
+    instance: Optional[str] = None
+
+    class Config:
+        validate_all = True
+        validate_assignment = True
+
+    def json(self):
+        return json.dumps(self, cls=PaymentEncoder)
+
+
 class Payment(BaseModel):
     id: UUID
     user_id: UUID
-    type: PaymentType
     tenant_id: UUID
-    remote_collection: RemoteCollectionType
+    config_id: UUID
     created_at: str
     updated_at: str
     status: PaymentStatus
-    reason: constr(max_length=140)
-    remote_id: UUID
+    fault: Optional[Fault]
+    remote_collection: RemoteCollectionType
     payment: PaymentData
     links: Links
     payer: Payer
+    debtor: Debtor
+    locale: str = None
     event_id: UUID
     event_version: str
     event_created_at: str
@@ -267,9 +324,9 @@ class Payment(BaseModel):
     updated_at_must_be_iso8601 = validator('updated_at', allow_reuse=True)(check_iso_format)
 
     @validator('event_version')
-    def event_version_must_be_two(cls, v):
-        if float(v) != 2.0:
-            raise ValidationError('event must have 2.0 as version')
+    def event_version_must_be_three(cls, v):
+        if float(v) != 3.0:
+            raise ValidationError('event must have 3.0 as version')
         return v.title()
 
     event_created_at_must_be_iso8601 = validator('event_created_at', allow_reuse=True)(check_iso_format)
@@ -329,7 +386,7 @@ class Payment(BaseModel):
 
     def is_payment_creation_needed(self):
         if self.status != PaymentStatus.STATUS_CREATION_PENDING:
-            logger.info(f'Event {self.id} from application {self.remote_id}: Payment creation not required')
+            logger.info(f'Event {self.id} from application {self.remote_collection.id}: Payment creation not required')
             return False
         return True
 
