@@ -98,6 +98,7 @@ def get_application_data(
         'integrations': [],
         'backoffice_data': None,
         'flow_changed_at': '2022-04-28T11:18:41+02:00',
+        'locale': 'IT',
         'event_version': '2.0',
         'event_id': 'bb7044e4-066c-4bf7-915e-87ee97270eae',
         **kwargs,
@@ -150,67 +151,121 @@ def get_application_payment_data(**kwargs):
 def get_payment_event_data(**kwargs):
     return {
         'id': 'bb7044e4-066c-4bf7-915e-87ee97270eae',
-        'user_id': '43f619df-3ba2-4d9d-bcdd-270484eac44d',
-        'type': 'PAGOPA',
-        'tenant_id': '2eeb8374-c8f9-4260-9e94-22504e262eb1',
+        'user_id': 'f3323b10-db62-4aeb-95de-a87c1f678dad',
+        'tenant_id': '60e35f02-1509-408c-b101-3b1a28109329',
+        'config_id': '68dada78-2398-4a11-b80a-98aaede3371c',
+        'created_at': '2024-02-19T15:50:23+01:00',
+        'updated_at': '2024-02-20T15:05:16+01:00',
+        'status': 'PAYMENT_PENDING',
+        'fault': None,
         'remote_collection': {
-            'id': 'cf9ece67-1956-49c9-af89-a19120485fef',
+            'id': '218d7772-a747-4d5f-8c56-bbc7cfeab1a0',
             'type': 'application',
         },
-        'created_at': '2022-06-08T08:28:42+00:00',
-        'updated_at': '2022-06-08T10:29:39+02:00',
-        'status': 'CREATION_PENDING',
-        'reason': 'a51cc065-4fb1-4ace-8d3f-e3a70c867472 - SLVLNZ76P01g843v',
-        'remote_id': 'a51cc065-4fb1-4ace-8d3f-e3a70c867472',
         'payment': {
             'transaction_id': None,
             'paid_at': None,
-            'expire_at': '2022-09-06T10:28:42+02:00',
-            'amount': 1,
+            'expire_at': '2023-09-04T11:59:05+02:00',
+            'amount': 16,
             'currency': 'EUR',
-            'notice_code': None,
-            'iud': 'bb7044e4066c4bf7915e87ee97270eae',
-            'iuv': None,
-            'split': [],
-            'stamps': [],
+            'type': 'STAMP',
+            'reason': 'bla',
+            'notice_code': '001550000000024427',
+            'iud': '68dada7823984a11b80a98aaede3371c',
+            'iuv': '550000000024427',
+            'receiver': {
+                'tax_identification_number': '777777777',
+                'name': 'Comune di BlaBla',
+                'iban': 'IT60X0542811101000000123456',
+                'address': 'Via Del Campo',
+                'building_number': '12',
+                'postal_code': '38022',
+                'town_name': 'Roma',
+                'country_subdivision': 'RM',
+                'country': 'IT',
+            },
+            'due_type': 'TARI',
+            'pagopa_category': '9/12129/TS',
+            'document': {
+                'id': '123',
+                'ref': 'http://example.com/api/documents/123',
+                'hash': 'sha256:12398r4o32kjm534om543523489k23jn',
+            },
+            'split': [
+                {
+                    'code': 'c_1',
+                    'amount': 0.5,
+                    'meta': {},
+                },
+                {
+                    'code': 'c_2',
+                    'amount': 0.5,
+                    'meta': {},
+                },
+            ],
         },
         'links': {
-            'online_payment_begin': {'url': None, 'last_opened_at': None, 'method': 'GET'},
+            'online_payment_begin': {
+                'url': 'https://example.com/online-payment/0452545f-40a9-4366-99b6-bbfb2b17b405',
+                'last_opened_at': None,
+                'method': 'GET',
+            },
             'online_payment_landing': {
-                'url': 'https://devsdc.opencontent.it/'
-                'comune-di-bugliano/it/pratiche/a51cc065-4fb1-4ace-8d3f-e3a70c867472/detail',
+                'url': 'https://example.com/lang/it/pratiche/1a9190cc-25cc-447c-a670-8d828dc0d1ea/detail',
+                'last_opened_at': None,
+                'method': 'GET',
+            },
+            'offline_payment': {
+                'url': 'https://example.com/notice/0452545f-40a9-4366-99b6-bbfb2b17b405',
+                'last_opened_at': None,
+                'method': 'GET',
+            },
+            'receipt': {
+                'url': 'https://example.com/receipt/0452545f-40a9-4366-99b6-bbfb2b17b405',
                 'last_opened_at': None,
                 'method': 'GET',
             },
-            'offline_payment': {'url': None, 'last_opened_at': None, 'method': 'GET'},
-            'receipt': {'url': None, 'last_opened_at': None, 'method': 'GET'},
             'notify': [
                 {
-                    'url': 'https://devsdc.opencontent.it/'
-                    'comune-di-bugliano/api/applications/a51cc065-4fb1-4ace-8d3f-e3a70c867472/payment',
+                    'url': 'https://example.com/lang/api/applications/1a9190cc-25cc-447c-a670-8d828dc0d1ea/payment',
                     'method': 'POST',
                     'sent_at': None,
                 },
             ],
             'update': {'url': None, 'last_check_at': None, 'next_check_at': None, 'method': 'GET'},
+            'confirm': {'url': None, 'last_check_at': None, 'next_check_at': None, 'method': 'PATCH'},
+            'cancel': {'url': None, 'last_check_at': None, 'next_check_at': None, 'method': 'PATCH'},
         },
         'payer': {
             'type': 'human',
-            'tax_identification_number': 'SLVLNZ76P01G843V',
-            'name': 'Lorenzo',
-            'family_name': 'Salvadorini',
-            'street_name': None,
-            'building_number': None,
-            'postal_code': None,
-            'town_name': None,
-            'country_subdivision': None,
+            'tax_identification_number': 'BNRMHL75C06G702B',
+            'name': 'Michelangelo',
+            'family_name': 'Buonarroti',
+            'street_name': 'Cesare Battisti',
+            'building_number': '',
+            'postal_code': '38010',
+            'town_name': 'Bugliano',
+            'country_subdivision': 'PI',
             'country': 'IT',
-            'email': 'raffaele.luccisano@opencontent.it',
+            'email': 'user@example.com',
         },
-        'event_id': 'c5cebc1a-5d6f-4921-bc15-ff0575ea6f75',
-        'event_version': '2.0',
-        'event_created_at': '2022-06-08T08:28:42+00:00',
-        'app_id': 'payment-dispatcher:1.0.15',
+        'debtor': {
+            'type': 'human',
+            'tax_identification_number': 'BNRMHL75C06G702B',
+            'name': 'Michelangelo',
+            'family_name': 'Buonarroti',
+            'street_name': 'Cesare Battisti',
+            'building_number': '',
+            'postal_code': '38010',
+            'town_name': 'Bugliano',
+            'country_subdivision': 'PI',
+            'country': 'IT',
+            'email': 'user@example.com',
+        },
+        'event_id': 'c80a2a33-577a-49a1-b578-0d2267ea5653',
+        'event_version': '3.0',
+        'event_created_at': '2024-02-20T15:05:16+01:00',
+        'app_id': 'mypay-payment-proxy:1.8.0',
         **kwargs,
     }
 
@@ -219,14 +274,106 @@ def get_payment_data(**kwargs):
     return {
         'transaction_id': None,
         'paid_at': None,
-        'expire_at': '2022-09-06T10:28:42+02:00',
-        'amount': 1,
+        'expire_at': '2023-09-04T11:59:05+02:00',
+        'amount': 16,
         'currency': 'EUR',
-        'notice_code': None,
-        'iud': 'bb7044e4066c4bf7915e87ee97270eae',
-        'iuv': None,
-        'split': [],
-        'stamps': [],
+        'type': 'STAMP',
+        'reason': 'bla',
+        'notice_code': '001550000000024427',
+        'iud': '68dada7823984a11b80a98aaede3371c',
+        'iuv': '550000000024427',
+        'receiver': {
+            'tax_identification_number': '777777777',
+            'name': 'Comune di BlaBla',
+            'iban': 'IT60X0542811101000000123456',
+            'address': 'Via Del Campo',
+            'building_number': '12',
+            'postal_code': '38022',
+            'town_name': 'Roma',
+            'country_subdivision': 'RM',
+            'country': 'IT',
+        },
+        'due_type': 'TARI',
+        'pagopa_category': '9/12129/TS',
+        'document': {
+            'id': '123',
+            'ref': 'http://example.com/api/documents/123',
+            'hash': 'sha256:12398r4o32kjm534om543523489k23jn',
+        },
+        'split': [
+            {
+                'code': 'c_1',
+                'amount': 0.5,
+                'meta': {},
+            },
+            {
+                'code': 'c_2',
+                'amount': 0.5,
+                'meta': {},
+            },
+        ],
+        **kwargs,
+    }
+
+
+def get_payment_data_item(**kwargs):
+    return {
+        'type': 'PAGOPA',
+        'amount': 1,
+        'reason': 'bla',
+        'notice_code': '001550000000024427',
+        'iud': '68dada7823984a11b80a98aaede3371c',
+        'iuv': '550000000024427',
+        'receiver': {
+            'tax_identification_number': '777777777',
+            'name': 'Comune di BlaBla',
+            'iban': 'IT60X0542811101000000123456',
+            'address': 'Via Del Campo',
+            'building_number': '12',
+            'postal_code': '38022',
+            'town_name': 'Roma',
+            'country_subdivision': 'RM',
+            'country': 'IT',
+        },
+        'due_type': 'TARI',
+        'pagopa_category': '9/12129/TS',
+        'document': None,
+        'split': [
+            {
+                'code': 'c_1',
+                'amount': 0.5,
+                'meta': {},
+            },
+            {
+                'code': 'c_2',
+                'amount': 0.5,
+                'meta': {},
+            },
+        ],
+        **kwargs,
+    }
+
+
+def get_receiver(**kwargs):
+    return {
+        'tax_identification_number': '777777777',
+        'name': 'Comune di BlaBla',
+        'iban': 'IT60X0542811101000000123456',
+        'address': 'Via Del Campo',
+        'building_number': '12',
+        'postal_code': '38022',
+        'town_name': 'Roma',
+        'country_subdivision': 'RM',
+        'country': 'IT',
+        **kwargs,
+    }
+
+
+def get_document(**kwargs):
+    return {
+        'id': '123',
+        'ref': 'http://example.com/api/documents/123',
+        'hash': 'sha256:12398r4o32kjm534om543523489k23jn',
         **kwargs,
     }
 
@@ -285,23 +432,6 @@ def get_stamps_data(**kwargs):
     }
 
 
-def get_stamps_data_complete():
-    return [
-        {
-            'amount': '16.00',
-            'collection_data': '9/123',
-            'reason': 'a51cc065-4fb1-4ace-8d3f-e3a70c867472 - SLVLNZ76P01g843v',
-            'meta': {},
-        },
-        {
-            'amount': '16.00',
-            'collection_data': '9/123',
-            'reason': 'a51cc065-4fb1-4ace-8d3f-e3a70c867472 - SLVLNZ76P01g843v',
-            'meta': {},
-        },
-    ]
-
-
 def get_payer_data(**kwargs):
     return {
         'type': 'human',
@@ -320,6 +450,32 @@ def get_payer_data(**kwargs):
 
 
 def get_links_data(**kwargs):
+    return {
+        'online_payment_begin': {'url': None, 'last_opened_at': None, 'method': 'GET'},
+        'online_payment_landing': {
+            'url': 'https://devsdc.opencontent.it/'
+            'comune-di-bugliano/it/pratiche/a51cc065-4fb1-4ace-8d3f-e3a70c867472/detail',
+            'last_opened_at': None,
+            'method': 'GET',
+        },
+        'offline_payment': {'url': None, 'last_opened_at': None, 'method': 'GET'},
+        'receipt': {'url': None, 'last_opened_at': None, 'method': 'GET'},
+        'notify': [
+            {
+                'url': 'https://devsdc.opencontent.it/'
+                'comune-di-bugliano/api/applications/a51cc065-4fb1-4ace-8d3f-e3a70c867472/payment',
+                'method': 'POST',
+                'sent_at': None,
+            },
+        ],
+        'update': {'url': None, 'last_check_at': None, 'next_check_at': None, 'method': 'GET'},
+        'confirm': {'url': None, 'last_check_at': None, 'next_check_at': None, 'method': 'PATCH'},
+        'cancel': {'url': None, 'last_check_at': None, 'next_check_at': None, 'method': 'PATCH'},
+        **kwargs,
+    }
+
+
+def get_links_data_without_cancel_and_confirm(**kwargs):
     return {
         'online_payment_begin': {'url': None, 'last_opened_at': None, 'method': 'GET'},
         'online_payment_landing': {
